#[macro_use]
mod test;

mod assert_stdout;
mod assert_success;
mod choose;
mod command;
mod common;
mod completions;
mod conditional;
mod delimiters;
mod dotenv;
mod edit;
mod error_messages;
mod evaluate;
mod examples;
mod export;
mod fmt;
mod functions;
mod init;
mod interrupts;
mod invocation_directory;
mod misc;
mod positional_arguments;
mod quiet;
mod readme;
mod search;
mod shebang;
mod shell;
mod string;
mod sublime_syntax;
mod subsequents;
mod tempdir;
mod working_directory;
